@@ -87,7 +87,7 @@ class ArgumentsMixin:
 
             # Call use_args (from webargs) to inject params in function
             return self.ARGUMENTS_PARSER.use_args(
-                schema, locations=[location], **kwargs)(wrapper)
+                schema, location=location, **kwargs)(wrapper)
 
         return decorator
 
